@@ -1,6 +1,6 @@
-from django.test import TestCase
+from unittest import TestCase
 
-from .teamgen import (Meeting, MatchRound, Team, Player)
+from teamgen import (Meeting, MatchRound, Team, Player)
 
 
 class TestBalancedRound:
